@@ -386,7 +386,7 @@ def parse_dox_html(stream):
     for example if the documentation contains raw HTML.
 
     The key/value block is kept in a comment so that it does not appear in Qt
-    Compressed Help output, which is not post processed by ourself.
+    Compressed Help output, which is not post processed by us.
     """
     dct = {}
     body = []
@@ -396,6 +396,8 @@ def parse_dox_html(stream):
             return parse_key_value_block
         if line == "-->":
             return skip_head
+        if line.startswith("<!DOCTYPE html"):
+            return skip_head
         key, value = line.split(': ', 1)
         dct[key] = value
         return parse_key_value_block
